@@ -10,6 +10,9 @@ sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 
 BEGIN {
   package POE::Kernel;
+BEGIN {
+  $POE::Kernel::VERSION = '1.312';
+}
   use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
 }
 
@@ -18,7 +21,11 @@ use Test::More;
 use POE qw(NFA);
 my $NEW_POE;
 BEGIN {
-  if (eval "$POE::VERSION" <= 1.003) {
+  # fixes Argument "1.294_272" isn't numeric in numeric le
+  my $poe_ver = eval("\$POE::VER" . "SION"); # Pesky CPAN indexer.
+  $poe_ver = $1 if $poe_ver =~ /^(?:[^_]+)\_/;
+
+  if ($poe_ver <= 1.003) { 
     $NEW_POE = 0;
     plan tests => 28;
   } else {
@@ -32,6 +39,9 @@ BEGIN {
 ### export conflicting constants.
 
 package Switch;
+BEGIN {
+  $Switch::VERSION = '1.312';
+}
 use POE::NFA;
 
 sub new {
@@ -134,6 +144,9 @@ POE::NFA->spawn(
 ### as it goes on and off.
 
 package Operator;
+BEGIN {
+  $Operator::VERSION = '1.312';
+}
 use POE::Session;
 
 POE::Session->create(
@@ -170,6 +183,9 @@ POE::Session->create(
 ### number you want, and it calculates and returns it.
 
 package FibServer;
+BEGIN {
+  $FibServer::VERSION = '1.312';
+}
 use POE::NFA;
 
 POE::NFA->spawn(
@@ -227,6 +243,9 @@ POE::NFA->spawn(
 ### responses vs. expectations.
 
 package FibClient;
+BEGIN {
+  $FibClient::VERSION = '1.312';
+}
 use POE::Session;
 
 my $test_number = 11;
@@ -273,6 +292,9 @@ POE::Session->create(
 ### Also tests options, and (call|post)backs
 
 package DynamicStates;
+BEGIN {
+  $DynamicStates::VERSION = '1.312';
+}
 use POE::NFA;
 
 POE::NFA->spawn(
@@ -331,6 +353,9 @@ POE::NFA->spawn(
 ### Run everything until it's all done.
 
 package main;
+BEGIN {
+  $main::VERSION = '1.312';
+}
 
 POE::Kernel->run();
 
